@@ -180,7 +180,7 @@ bonobo_transient_get_servant_locator_vepv (void)
  * This function is only for wrappers and object derivation.  For normal
  * use, please see #bonobo_transient_new.
  *
- * This function will return %NULL on failiure, however it is your
+ * This function will return %NULL on failure; however it is your
  * responsibility to destroy the failed object in that case.
  *
  * Returns: a #BonoboTransient object (the @transient)
@@ -197,7 +197,8 @@ bonobo_transient_construct (BonoboTransient          *transient,
 	CORBA_Environment		 ev;
 	char				*poa_name;
 	gboolean			 success;
-
+	char                            *text;
+	
 	success = FALSE;
 
 	transient->priv->new_servant = new_servant;
@@ -295,9 +296,11 @@ bonobo_transient_construct (BonoboTransient          *transient,
 			&ev);
 	
 	if (BONOBO_EX (&ev)) {
-		g_warning ("Could not create servant retention policy for BonoboTransient POA '%s'",
-			   bonobo_exception_get_text (&ev));
+		text = bonobo_exception_get_text (&ev);
 		CORBA_exception_free (&ev);
+		g_warning ("Could not create servant retention policy for BonoboTransient POA '%s'",
+			   text);
+		g_free (text);
 		goto out;
 	}
 	
@@ -313,9 +316,11 @@ bonobo_transient_construct (BonoboTransient          *transient,
 			&ev);
 	
 	if (BONOBO_EX (&ev)){
-		g_warning ("Could not create threading policy for BonoboTransient POA '%s'",
-			   bonobo_exception_get_text (&ev));
+		text = bonobo_exception_get_text (&ev);
 		CORBA_exception_free (&ev);
+		g_warning ("Could not create threading policy for BonoboTransient POA '%s'",
+			   text);
+		g_free (text);
 		goto out;
 	}
 
@@ -326,9 +331,11 @@ bonobo_transient_construct (BonoboTransient          *transient,
 			&ev);
 
 	if (BONOBO_EX (&ev)){
-		g_warning ("Could not create activation policy for BonoboTransient POA '%s'",
-			   bonobo_exception_get_text (&ev));
+		text = bonobo_exception_get_text (&ev);
 		CORBA_exception_free (&ev);
+		g_warning ("Could not create activation policy for BonoboTransient POA '%s'",
+			   text);
+		g_free (text);
 		goto out;
 	}
 
@@ -343,9 +350,10 @@ bonobo_transient_construct (BonoboTransient          *transient,
 	g_free (poa_name);
 
 	if (BONOBO_EX (&ev)) {
-		g_warning ("BonoboTransient: Could not create BonoboTransient POA '%s'",
-			   bonobo_exception_get_text (&ev));
+		text = bonobo_exception_get_text (&ev);
 		CORBA_exception_free (&ev);
+		g_warning ("BonoboTransient: Could not create BonoboTransient POA '%s'",
+			   text);
 		goto out;
 	}
 	
