@@ -22,6 +22,8 @@
 */
 
 #include <unistd.h>
+#include <string.h>
+#include <stdlib.h>
 
 
 #include "efs.h"
